@@ -5,9 +5,12 @@ import random
 import re
 import string
 import threading
-from typing import Any, Callable, Coroutine, List, Optional, TypeVar, Union, cast
+from inspect import signature
+from typing import Any, Callable, Coroutine, List, Optional, Type, TypeVar, Union, cast
 
+from telebot import AsyncTeleBot
 from telebot.types import constants
+from telebot.types import service as service_types
 
 MAX_MESSAGE_LENGTH = 4096
 
@@ -61,16 +64,25 @@ def validated_str(v: Any, name: Optional[str] = None) -> str:
     return v
 
 
-def validated_list_content_type(v: Any, name: Optional[str] = None) -> list[constants.ContentType]:
+def _validated_list(v: Any, item_types: list[Type], name: Optional[str] = None) -> list:
     name = name or "<anonymous>"
+    item_types_str = ", ".join([it.__name__ for it in item_types])
     if not isinstance(v, list):
-        raise TypeError(f"{name} is expected to be list[ContentType], but it's not even a list")
+        raise TypeError(f"{name} is expected to be list of {item_types_str} but it's not even a list")
     for item in v:
-        if not isinstance(item, (constants.ServiceContentType, constants.MediaContentType)):
-            raise TypeError(f"{name} is expected to be list[ContentType], but includes invalid item '{item}'")
+        if not isinstance(item, tuple(item_types)):
+            raise TypeError(f"{name} is expected to be list of {item_types_str} but includes invalid item '{item}'")
     return v
 
 
+def validated_list_content_type(v: Any, name: Optional[str] = None) -> list[constants.ContentType]:
+    return _validated_list(v, item_types=[constants.ServiceContentType, constants.MediaContentType], name=name)
+
+
+def validated_list_chat_type(v: Any, name: Optional[str] = None) -> list[constants.ChatType]:
+    return _validated_list(v, item_types=[constants.ChatType], name=name)
+
+
 def is_command(text: str) -> bool:
     r"""
     Checks if `text` is a command. Telegram chat commands start with the '/' character.
@@ -265,3 +277,20 @@ def deprecated(warn: bool = True, alternative: Optional[Callable] = None, deprec
         return wrapper
 
     return decorator
+
+
+async def invoke_hanlder(
+    handler_func: service_types.HandlerFunction, bot: AsyncTeleBot, update_content: service_types.UpdateContent
+) -> None:
+    arg_count = len(list(signature(handler_func).parameters.keys()))
+    if arg_count == 1:
+        await handler_func(update_content)
+        return
+    elif arg_count == 2:
+        await handler_func(update_content, bot)
+        return
+    else:
+        raise TypeError(
+            "Handler function must have one (update content) or two (update content and bot) parameters, "
+            + f"but found function with {arg_count} params"
+        )
